pub struct TimsDataset {
pub loader: TimsDataLoader,
}Fields
loader: TimsDataLoaderImplementations
Sourceimpl TimsDataset
impl TimsDataset
pub fn new( bruker_lib_path: &str, data_path: &str, in_memory: bool, use_bruker_sdk: bool, ) -> Self
Sourcepub fn new_with_calibration(
data_path: &str,
in_memory: bool,
im_lookup: Vec<f64>,
) -> Self
pub fn new_with_calibration( data_path: &str, in_memory: bool, im_lookup: Vec<f64>, ) -> Self
Create a new dataset with pre-computed ion mobility calibration lookup table.
This enables accurate ion mobility calibration with fast parallel extraction. The im_lookup table should be pre-computed using the Bruker SDK.
Arguments
data_path- Path to the .d folderin_memory- Whether to load all data into memoryim_lookup- Pre-computed scan→1/K0 lookup table from Bruker SDK
Returns
A new TimsDataset with LookupIndexConverter
Sourcepub fn uses_bruker_sdk(&self) -> bool
pub fn uses_bruker_sdk(&self) -> bool
Check if the Bruker SDK is being used for index conversion. Returns false for both Simple and Lookup converters (which are thread-safe).